List and describe the various models available in the API.
oai_list_models(): Retrieve a data frame of models.
oai_retrieve_model(): Retrieve a model.
oai_delete_model(): Delete a model.
List and describe the various models available in the API.
oai_list_models(): Retrieve a data frame of models.
oai_retrieve_model(): Retrieve a model.
oai_delete_model(): Delete a model.