Message R6 class
Message R6 class
Public fields
idCharacter. The ID of the message.
created_atPOSIXct. The time the message was created.
thread_idCharacter. The ID of the thread this message belongs to.
statusCharacter. The status of the message.
incomplete_detailsList. Details about the message if it is incomplete.
completed_atPOSIXct. The time the message was completed.
incomplete_atPOSIXct. The time the message was marked as incomplete.
roleCharacter. The role of the sender.
contentList. The content of the message.
assistant_idCharacter. If applicable, the ID of the assistant that authored this message.
run_idCharacter. The ID of the run associated with the creation of this message. Value is null when messages are created manually using the create message or create thread endpoints.
attachmentsList. Attachments to the message.
metadataList. Metadata associated with the message.
Methods
Method new()
Initialize a Message object.
Usage
Message$new(
message_id = NULL,
thread_id = NULL,
...,
resp = NULL,
.async = FALSE
)