VectorStoreFile R6 class
VectorStoreFile R6 class
Public fields
idCharacter. The ID of the vector store file.
attributesNamed list. A list of attributes associated with the vector store file.
created_atPOSIXct. The time the vector store file was created.
statusCharacter. The status of the vector store file. One of "in_progress", "completed", "failed", "cancelled".
chunking_strategyList. The strategy used to chunk the data.
usage_bytesInteger. The number of bytes used by the vector store file.
vector_store_idCharacter. The ID of the vector store that the file belongs to.
last_errorCharacter. The last error that occurred while processing the file.
Methods
Method new()
Initialize a new VectorStoreFile object. Either provide a vector_store_file_id or a vector_store_id together with a file_id or a path to a file.
Usage
VectorStoreFile$new(
vector_store_file_id = NULL,
vector_store_id = NULL,
file_id = NULL,
path = NULL,
resp = NULL
)Arguments
vector_store_file_idCharacter. The ID of the vector store file.
vector_store_idCharacter. The ID of the vector store that the file belongs to.
file_idCharacter. The ID of the file that the vector store file is associated with.
pathCharacter. The path to the file that the vector store file is associated with.
respList. The response object from the OpenAI API.
Method update()
Update the vector store file in the OpenAI API.
Method print()
Print the vector store file.