VectorStoreFilesBatch R6 class
VectorStoreFilesBatch R6 class
Public fields
idCharacter. The ID of the file batch.
attributesList. The attributes of the file batch.
created_atPOSIXct. The date and time the file batch was created.
vector_store_idCharacter. The ID of the vector store where the file batch was created.
statusCharacter. The status of the file batch.
file_countsList. The number of files in the batch.
Methods
Method new()
Initialize a VectorStoreFilesBatch object. The ... argument is passed to the API functions.
Usage
VectorStoreFilesBatch$new(
vector_store_id = NULL,
batch_id = NULL,
file_ids = NULL,
paths = NULL,
...,
resp = NULL
)Arguments
vector_store_idCharacter. The ID of the vector store where the file batch will be created.
batch_idCharacter. The ID of the batch to retrieve.
file_idsCharacter. A vector of file IDs to include in the batch.
pathsCharacter. A vector of file paths to include in the batch.
...Additional arguments passed to the API functions.
respList. The response from the API.
Method list_files()
List all files in the file batch. The ... argument is passed to oai_list_vector_store_files().
Method print()
Print the file batch.