Transcription object Represents a transcription response returned by model, based on the provided input.
Source:R/audio.R
audio_transcription.RdTranscription object Represents a transcription response returned by model, based on the provided input.
Transcription object Represents a transcription response returned by model, based on the provided input.
Verbose transcription object Represents a verbose json transcription response returned by model, based on the provided input.
Verbose transcription object Represents a verbose json transcription response returned by model, based on the provided input.
Methods
Public fields
languageCharacter. The language of the input audio.
durationCharacter. The duration of the input audio.
textCharacter. The transcribed text.
wordsList. Extracted words and their corresponding timestamps.
segmentsList. Segments of the transcribed text and their corresponding details.
Methods
Method new()
Initialize the VerboseTranscription object.
Usage
VerboseTranscription$new(..., resp = NULL)